@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: WriteLocker.h 2756 2007-12-11 10:57:59Z svn $
+ * $Id: WriteLocker.h 2822 2008-03-15 14:41:22Z svn $
  *****************************************************************************/
 
 #ifndef WRITE_LOCKER_H
@@ -47,7 +47,11 @@ public:
      *
      * @param[in] lock ロック変数
      */
-    WriteLocker(apr_atomic_t *lock)
+    WriteLocker(apr_atomic_t *lock
+#ifdef DEBUG_ReadWriteLocker
+                , apr_thread_mutex_t *mutex
+#endif
+                )
       : ReadWriteLocker()
     {
         apr_size_t try_count;
@@ -61,7 +65,11 @@ public:
             if (get_read_count(curr_status) == NOT_LOCKED) {
                 new_status = (curr_status | WRITE_LOCKED) & (~WAIT_WRITE);
                 prev_status = apr_atomic_cas(lock, new_status, curr_status);
-                init(lock, new_status);
+                init(lock, new_status
+#ifdef DEBUG_ReadWriteLocker
+                     , mutex
+#endif
+                     );
                 if (prev_status == curr_status) {
                     log_try_count("WriteLock",
                                   try_count, curr_status, new_status);
@@ -74,7 +82,11 @@ public:
                     new_status = (curr_status | WRITE_LOCKED) & (~WAIT_WRITE);
                     new_status += AGE_UINIT;
                     prev_status = apr_atomic_cas(lock, new_status, curr_status);
-                    init(lock, new_status);
+                    init(lock, new_status
+#ifdef DEBUG_ReadWriteLocker
+                     , mutex
+#endif
+                         );
                     if (prev_status == curr_status) {
                         log_try_count("WriteLock(TIME OUT)",
                                       try_count, curr_status, new_status);
