@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateVariableCreator.cpp 2756 2007-12-11 10:57:59Z svn $
+ * $Id: TemplateVariableCreator.cpp 2867 2008-04-24 14:59:46Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -34,7 +34,7 @@
 #include "Macro.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: TemplateVariableCreator.cpp 2756 2007-12-11 10:57:59Z svn $");
+SOURCE_INFO_ADD("$Id: TemplateVariableCreator.cpp 2867 2008-04-24 14:59:46Z svn $");
 
 const apr_size_t TemplateVariableCreator::VAR_SCR_POOL_SIZE = 10;
 
@@ -128,6 +128,11 @@ apr_size_t TemplateVariableCreator::get_array_memory_size(apr_array_header_t *ar
         size += strlen(AS_CONST_CHAR_P(array->elts)[i]) + 1;
     }
 
+    // 処理の都合上 4 の倍数に丸める
+    if (size & 3) {
+        size = (size & ~3) + 4;
+    }
+
     return size;
 }
 
