@@ -3,14 +3,14 @@
 sub encode {
     my $data = shift;
 
-    $data =~ s/([^\w ])/'\\x' . unpack('H2', $1)/eg;
+    $data =~ s/(.)/'\\x' . unpack('H2', $1)/eg;
 
     return $data;
 }
 
 while (my $line = <>) {
     if ($line =~ /^#define /) {
-        $line =~ s/"(.+)"\r\n$/'"' . encode($1) . '"' . "\r\n"/e;
+        $line =~ s/"(.+)"$/'"' . encode($1) . '"'/e;
     }
     print $line;
 }
